fsmode

package
v0.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 9, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ComponentGVK          = schema.GroupVersionKind{Group: "openchoreo.dev", Version: "v1alpha1", Kind: "Component"}
	ComponentTypeGVK      = schema.GroupVersionKind{Group: "openchoreo.dev", Version: "v1alpha1", Kind: "ComponentType"}
	WorkloadGVK           = schema.GroupVersionKind{Group: "openchoreo.dev", Version: "v1alpha1", Kind: "Workload"}
	TraitGVK              = schema.GroupVersionKind{Group: "openchoreo.dev", Version: "v1alpha1", Kind: "Trait"}
	ComponentReleaseGVK   = schema.GroupVersionKind{Group: "openchoreo.dev", Version: "v1alpha1", Kind: "ComponentRelease"}
	ReleaseBindingGVK     = schema.GroupVersionKind{Group: "openchoreo.dev", Version: "v1alpha1", Kind: "ReleaseBinding"}
	DeploymentPipelineGVK = schema.GroupVersionKind{Group: "openchoreo.dev", Version: "v1alpha1", Kind: "DeploymentPipeline"}
	ProjectGVK            = schema.GroupVersionKind{Group: "openchoreo.dev", Version: "v1alpha1", Kind: "Project"}
	EnvironmentGVK        = schema.GroupVersionKind{Group: "openchoreo.dev", Version: "v1alpha1", Kind: "Environment"}
	DataPlaneGVK          = schema.GroupVersionKind{Group: "openchoreo.dev", Version: "v1alpha1", Kind: "DataPlane"}
)

OpenChoreo resource GroupVersionKinds

Functions

This section is empty.

Types

type Index

type Index struct {
	*index.Index
	// contains filtered or unexported fields
}

Index wraps the generic index with OpenChoreo-specific functionality

func WrapIndex

func WrapIndex(idx *index.Index) *Index

WrapIndex wraps an existing generic index with OpenChoreo-specific functionality

func (*Index) GetComponent

func (idx *Index) GetComponent(namespace, name string) (*index.ResourceEntry, bool)

GetComponent retrieves a component by namespace and name

func (*Index) GetComponentType

func (idx *Index) GetComponentType(name string) (*index.ResourceEntry, bool)

GetComponentType retrieves a component type by name

func (*Index) GetDeploymentPipeline

func (idx *Index) GetDeploymentPipeline(name string) (*index.ResourceEntry, bool)

GetDeploymentPipeline retrieves a deployment pipeline by name

func (*Index) GetLatestReleaseForComponent

func (idx *Index) GetLatestReleaseForComponent(projectName, componentName string) (*index.ResourceEntry, error)

GetLatestReleaseForComponent returns the latest component release for a specific component Releases are sorted by name (which includes date and version), so the last one is the latest

func (*Index) GetReleaseBindingForEnv

func (idx *Index) GetReleaseBindingForEnv(projectName, componentName, envName string) (*index.ResourceEntry, bool)

GetReleaseBindingForEnv retrieves a release binding for a specific component and environment Returns the first binding found for the given component and environment

func (*Index) GetTrait

func (idx *Index) GetTrait(name string) (*index.ResourceEntry, bool)

GetTrait retrieves a trait by name

func (*Index) GetTypedComponent

func (idx *Index) GetTypedComponent(namespace, name string) (*typed2.Component, error)

GetTypedComponent retrieves a component by namespace and name and returns a typed wrapper

func (*Index) GetTypedComponentType

func (idx *Index) GetTypedComponentType(name string) (*typed2.ComponentType, error)

GetTypedComponentType retrieves a component type by name and returns a typed wrapper

func (*Index) GetTypedTrait

func (idx *Index) GetTypedTrait(name string) (*typed2.Trait, error)

GetTypedTrait retrieves a trait by name and returns a typed wrapper

func (*Index) GetTypedWorkloadForComponent

func (idx *Index) GetTypedWorkloadForComponent(projectName, componentName string) (*typed2.Workload, error)

GetTypedWorkloadForComponent retrieves the workload for a specific component and returns a typed wrapper

func (*Index) GetWorkloadForComponent

func (idx *Index) GetWorkloadForComponent(projectName, componentName string) (*index.ResourceEntry, bool)

GetWorkloadForComponent retrieves the workload for a specific component

func (*Index) ListComponents

func (idx *Index) ListComponents() []*index.ResourceEntry

ListComponents returns all components

func (*Index) ListComponentsForProject

func (idx *Index) ListComponentsForProject(projectName string) []*index.ResourceEntry

ListComponentsForProject returns all components for a specific project

func (*Index) ListReleaseBindings

func (idx *Index) ListReleaseBindings() []*index.ResourceEntry

ListReleaseBindings returns all release bindings

func (*Index) ListReleases

func (idx *Index) ListReleases() []*index.ResourceEntry

ListReleases returns all component releases

func (*Index) ListReleasesForComponent

func (idx *Index) ListReleasesForComponent(projectName, componentName string) []*index.ResourceEntry

ListReleasesForComponent returns all component releases for a specific component

type OwnerRef

type OwnerRef struct {
	ProjectName   string
	ComponentName string
}

OwnerRef represents OpenChoreo-specific owner reference information

func ExtractOwnerRef

func ExtractOwnerRef(entry *index.ResourceEntry) *OwnerRef

ExtractOwnerRef extracts owner reference information from a resource entry

Directories

Path Synopsis

Jump to